教父 (豆瓣)
Description: 教父电影简介和剧情介绍,教父影评、图片、预告片、影讯、论坛、在线购票
Keywords: 教父,The Godfather,教父影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.22豆瓣电影Top250

# 教父 The Godfather (1972)

更新描述或海报

导演: 弗朗西斯·福特·科波拉
编剧: 马里奥·普佐 / 弗朗西斯·福特·科波拉
主演: 马龙·白兰度 / 阿尔·帕西诺 / 詹姆斯·肯恩 / 理查德·卡斯特尔诺 / 罗伯特·杜瓦尔 / 斯特林·海登 / 约翰·马利 / 理查德·康特 / 艾尔·勒提埃里 / 黛安·基顿 / 阿贝·维高达 / 塔莉娅·夏尔 / 吉亚尼·罗素 / 约翰·凯泽尔 / 鲁迪·邦德 / 兰尼·蒙大拿
类型: 剧情 / 犯罪
制片国家/地区: 美国
语言: 英语 / 意大利语 / 拉丁语
上映日期: 1972-03-15(纽约首映) / 1972-03-24(美国)
片长: 175 分钟
又名: Mario Puzo's The Godfather
IMDb: tt0068646
豆瓣评分
引用
9.3
913380人评价
5星
72.0%
4星
22.9%
3星
4.5%
2星
0.4%
1星
0.2%
好友评分
你关注的人看过这部作品的平均分
9.0
4人评价
好于 99% 犯罪片
好于 99% 剧情片
想看 看过
评价:
推荐

## 教父的剧情简介 · · · · · ·

40年代的美国，“教父”维托·柯里昂（马龙·白兰度 饰）是黑手党柯里昂家族的首领，带领家族从事非法的勾当，但同时他也是许多弱小平民的保护神，深得人们爱戴。
因为拒绝了毒枭索洛索的毒品交易要求，柯里昂家族和纽约其他几个黑手党家族的矛盾激化。圣诞前夕，索洛索劫持了“教父”的参谋汤姆，并派人暗杀“教父”；因为内奸的出卖，“教父”的大儿子逊尼被仇家杀害；小儿子麦克（阿尔·帕西诺 饰）也被卷了进来，失去爱妻。黑手党家族之间的矛盾越来越白热化。
年老的“教父”面对丧子之痛怎样统领全局？黑手党之间的仇杀如何落幕？谁是家族的内奸？谁又能够成为新一代的“教父”？
血雨腥风和温情脉脉，在这部里程碑式的黑帮史诗巨片里真实上演。 ©豆瓣

## 教父的演职员 · · · · · · ( 全部 45 )

- 弗朗西斯·福特·科波拉 导演
- 马龙·白兰度 饰 Don Vito Corleone
- 阿尔·帕西诺 饰 Michael Corleone
- 詹姆斯·肯恩 饰 Sonny Corleone
- 理查德·卡斯特尔诺 饰 Clemenza
- 罗伯特·杜瓦尔 饰 Tom Hagen

## 教父的视频和图片 · · · · · · ( 预告片3 | 视频评论1 · 添加 | 图片1920 · 添加 )

## 教父的获奖情况 · · · · · · ( 全部 )

- 第45届奥斯卡金像奖
- 最佳影片
- 艾伯特·S·拉迪

- 第45届奥斯卡金像奖
- 最佳导演(提名)
- 弗朗西斯·福特·科波拉

- 第45届奥斯卡金像奖
- 最佳男主角
- 马龙·白兰度

## 喜欢这部电影的人也喜欢 · · · · · ·

  教父2

  美国往事

  猫鼠游戏

  无间道

  低俗小说

  英雄本色

  上帝之城

  黑社会

  枪火

  两杆大烟枪

我要写短评

## 教父的短评 · · · · · · ( 全部 156817 条 )

热门 / 最新 / 好友

### 7004 有用 账号弃用 看过 2009-07-24 17:06:54

"Because a man who doesn't spend time with his family can never be a real man."

### 3154 有用 私享史 看过 2005-11-25 16:11:11

当一个新生儿在教堂接受教父的洗礼时，教堂之外的死亡正在蔓延……

### 8078 有用 大头绿豆 看过 2005-09-12 20:08:33

男人。 千万不要记恨你的对手，这样会让你失去理智。

### 1348 有用 Q。 看过 2011-02-01 16:53:22

平缓的节奏蕴藏着巨大的权威和张力，音乐舒缓淡淡忧伤，利益博弈人性冲突。无论是演技还是镜头、音乐的运用，都给人以一种美的享受。而看这部电影是极其需要沉下心来细细品味，也无论何时翻出来重温都能有新的感受。★★★★☆

### 3108 有用 刘康康 看过 2014-05-26 02:33:29

科波拉是有厌女症吧？这片子里的女人要么圣母得让人恶心，要么就傻逼得遭人烦，除了哭哭啼啼就是无理取闹。最后一个镜头，麦克成为新的教父，一道门隔开他的妻子，不是没有理由的。这是一个男人的世界。相对来说我最喜欢医院里那场戏，拍得相当有张力，第一场婚礼戏也喜欢。

> 更多短评 156817条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2020-06-27 18:38:21

2020，07。麦克太帅了！如果可以早一点看《教父》，那该多好

我要写影评

## 教父的影评 · · · · · · ( 全部 1980 条 )

热门 / 最新 / 好友
猴子 2016-05-05 17:12:56

## 人生无常，世事难料

(展开)
0回应 收起

> 全部我关注的影评1篇

东遇西 2007-06-12 11:02:54

## 婚礼

星期天闲着无事，又找出《教父》杀时间。没有看完全片，却把第一场戏（段落）看了两遍。 然后还是叹服。如果说真的有个史上最牛B的电影开头，这个绝对当仁不让。 像《教父》这种史诗电影，庞大的故事架构，纷杂的人物关系，众多的情节起点，都需要在第一幕中全部建立起来，为后... (展开)
6639 187 280回应 收起
楚平 2007-04-22 08:27:25

## 安息吧，我尊敬的教父

我最爱的电影是《教父》。在这一点上，我可以同许多男人达成共识。马龙的表演实在令人心折。在少年时代，我深深着迷，甚至模仿他那含混不清的说话方式，却并不成功。一个平凡的小人物，喊破了嗓子也找不到认真的听众，那个口齿不清的教父，却没人敢忽略他说出的每一个字。他总... (展开)
6746 882 391回应 收起
azcat11 2009-05-17 11:03:13

## what a realist mean?

教父经典语录！一、人生与处世 1、生活是这样美丽。 2、一个人只有一个命运。 3、不要让别人知道你的想法。 4、不要让人知道你伸手要抓什么。 5、我们都是伪君子。 6、当你说不时,你要使不听上去象是一样好听。 7、我一生为家族服务，而不愿成为大人物手下的玩偶。 8、... (展开)
3357 160 181回应 收起
alice 2010-12-16 23:01:08

## Michael

这篇影评可能有剧透

纵观三部曲，正如第二部呈现的主题，讲的是新老两代教父的成长史，是他们人生的对比。他们分别在事业上取得了巨大的成功，维托白手起家，成为美国势力最大的黑社会头目；麦克在父亲的基础上，将事业扩展到西部及南部，使得家族成为一个极度庞大的帝国。 但人生并不只事业一条路... (展开)
1959 50 182回应 收起
塞西蒙得 2018-12-24 18:58:29

## 《教父》看不懂？完全无感？读完这篇再去看~

这篇影评可能有剧透

橘猫这两天突然跑去重看了《教父》，发现还是那么好看。 不过，橘猫很快又意识到，对于《教父》，作为老观众、老影迷自然能每一次重看都看出之前未能察觉的精彩。可对于新观众而言，这并不是一部非常“友善”的电影。所以，今天橘猫就从梳理和幕后两方面入手，来说说关于《教父... (展开)
1530 62回应 收起
蒋八怪 2012-04-03 18:30:47

## 《教父》四十年 一个影迷的纪念

这篇影评可能有剧透

第一句台词：我相信美国。如果哪天有部中国电影一上来，第一句：我相信中国。我想中国的观众会因为这句话，至少坚持30分钟。对着国家开炮，一上来就摆明：我是高分选手，不是来玩小儿科的。 第一场戏：“民间焦虑”。殡仪馆老板，相信美国，但美国没有给他公平。（这哥们还镶了... (展开)
1084 22 55回应 收起
东方快车 2010-12-08 15:31:51

## 关于《教父》的21点回忆

听说，斯坦利·库布里克(Stanley Kubrick)看《教父》看到第十遍的时候承认，这可能是历史上最伟大的电影。这样的天才看了十遍就下了这样 的定论，而我这样的庸才只看了一遍就完全被震撼了。不过我又看了将近五十遍，包括后边的两个续集，细算一下等于我花了五百个小时去... (展开)
639 34 46回应 收起
禾几九二 2018-08-25 16:56:03 #教父三部曲里你印象最深的一个细节？

## 「教父」里惨死的大儿子桑迪诺

这篇影评可能有剧透

在电影里，老教父的儿子桑迪诺被描写成一位鲁莽、自大、易怒、没头脑又性欲旺盛的二愣子。 然后，在一次得知自己妹妹被再次家暴后，急急上门教训妹夫的途中，被塔塔利亚家族的人埋伏于汽车收费站。 最终，这位有勇无谋的角色被机关枪打成了筛子。 其实马里奥·普佐在自己的原著... (展开)
272 4 47回应 收起
阿厚 2006-04-29 14:04:08

## 一切不能回头，按照江湖规矩办

据说《教父》前后三集拍了18年，关于这书和这电影的评论已经是汗牛充栋了。黑帮片和江湖片的经典之作应该非它莫属---最近的《无间道》似有出椽之势。引人的故事得力于原著魅力，其中的音乐现在比电影本身流传更甚，我只能谈演员的表演了。马龙-白兰度饰演的老教父永远是有些漫... (展开)
307 49 44回应 收起
安德烈大叔 2011-04-15 17:38:44

## 《教父》三部曲的前世今生

谨以此文向伟大的《教父》三部曲致以我最崇高的敬意。 很少有电影可以深刻的影响到一个常用词汇，如果真的存在这种现象，那就可以很好的说明这部电影影响之广、之深，很显然，《教父》三部曲就是这种电影，作为电影史上最伟大的黑帮电影（没有之一），《教父》系... (展开)
231 15 13回应 收起

> 更多影评 1980篇

添加新讨论

## 讨论区 · · · · · ·

为什么麦克打了索罗佐一枪，而给了警长两枪 | 来自不想起名字 | 2 回应 | 2022-11-24 15:46:06
以现在的目光来看教父是否缺乏投资远见？ | 来自旁白 | 2 回应 | 2022-11-22 10:54:49
为什么我看不下去 ？ | 来自One Day | 8 回应 | 2022-11-21 21:34:07
各位感觉中国演员有谁hold得住马龙白兰度这个角色 | 来自江南 | 101 回应 | 2022-11-20 16:08:04
《教父》价值观是什么？ | 来自王鑫 | 41 回应 | 2022-11-20 14:12:23

> 去这部影片的讨论区（全部539条）

## 关于《教父》的问题 · · · · · · ( 全部59个 )

- 谁给说说麦克跟索拉索和警察去吃饭那段俩意大利人用意大利语对话的内容？ 6人回答
- 为什么选麦克当家？ 21人回答

> 全部59个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 《电影手册》世上最美的100部电影 (大旗虎皮)
- {北美电影票房总排行} (荔枝超人)
- 最摇滚的100部电影！ (kulilin)
- 今敏《造梦机器》剧组100部电影推荐 (恶魔的步调)

## 谁在看这部电影 · · · · · ·

- 千层度
  3分钟前 看过
- lix的布朗尼
  4分钟前 看过
- 是君度ya
  5分钟前 看过

1483135人看过 / 475086人想看

订阅教父的评论:
feed: rss 2.0